@@ -2,14 +2,16 @@
 
 from .common import (
     Docstring,
+    DocstringDeprecated,
     DocstringMeta,
     DocstringParam,
     DocstringRaises,
     DocstringReturns,
-    ParseError,
 )
+from .common import DocstringStyle  # backwards compatibility
+from .common import DocstringStyle as Style
+from .common import ParseError
 from .parser import parse
-from .styles import Style
 
 __all__ = [
     "parse",
@@ -19,5 +21,7 @@ __all__ = [
     "DocstringParam",
     "DocstringRaises",
     "DocstringReturns",
+    "DocstringDeprecated",
+    "DocstringStyle",
     "Style",
 ]
