@@ -3,7 +3,7 @@
 import inspect
 import re
 import typing as T
-from collections import namedtuple, OrderedDict
+from collections import OrderedDict, namedtuple
 from enum import IntEnum
 
 from .common import (
@@ -16,6 +16,7 @@ from .common import (
     DocstringParam,
     DocstringRaises,
     DocstringReturns,
+    DocstringStyle,
     ParseError,
 )
 
@@ -186,7 +187,7 @@ class GoogleParser:
 
         :returns: parsed docstring
         """
-        ret = Docstring()
+        ret = Docstring(style=DocstringStyle.google)
         if not text:
             return ret
 
@@ -222,12 +223,20 @@ class GoogleParser:
             splits.append((matches[j].end(), matches[j + 1].start()))
         splits.append((matches[-1].end(), len(meta_chunk)))
 
-        chunks = OrderedDict()
+        chunks = OrderedDict()  # type: T.Mapping[str,str]
         for j, (start, end) in enumerate(splits):
             title = matches[j].group(1)
             if title not in self.sections:
                 continue
-            chunks[title] = meta_chunk[start:end].strip("\n")
+
+            # Clear Any Unknown Meta
+            # Ref: https://github.com/rr-/docstring_parser/issues/29
+            meta_details = meta_chunk[start:end]
+            unknown_meta = re.search(r"\n\S", meta_details)
+            if unknown_meta is not None:
+                meta_details = meta_details[: unknown_meta.start()]
+
+            chunks[title] = meta_details.strip("\n")
         if not chunks:
             return ret
 
