@@ -14,6 +14,7 @@ from .common import (
     DocstringParam,
     DocstringRaises,
     DocstringReturns,
+    DocstringStyle,
     ParseError,
 )
 
@@ -88,7 +89,7 @@ def parse(text: str) -> Docstring:
 
     :returns: parsed docstring
     """
-    ret = Docstring()
+    ret = Docstring(style=DocstringStyle.rest)
     if not text:
         return ret
 
