@@ -309,14 +309,14 @@ def test_default_args():
         """A sample function
 
     A function the demonstrates docstrings
-    
+
     Args:
         arg1 (int): The firsty arg
         arg2 (str): The second arg
         arg3 (float, optional): The third arg. Defaults to 1.0.
         arg4 (Optional[Dict[str, Any]], optional): The fourth arg. Defaults to None.
         arg5 (str, optional): The fifth arg. Defaults to DEFAULT_ARG5.
-    
+
     Returns:
         Mapping[str, Any]: The args packed in a mapping
     """
@@ -591,3 +591,28 @@ def test_broken_meta() -> None:
 
     with pytest.raises(ParseError):
         parse("Args:\n    herp derp")
+
+
+def test_unknown_meta() -> None:
+    docstring = parse(
+        """Short desc
+
+        Unknown 0:
+            title0: content0
+
+        Args:
+            arg0: desc0
+            arg1: desc1
+
+        Unknown1:
+            title1: content1
+
+        Unknown2:
+            title2: content2
+        """
+    )
+
+    assert docstring.params[0].arg_name == "arg0"
+    assert docstring.params[0].description == "desc0"
+    assert docstring.params[1].arg_name == "arg1"
+    assert docstring.params[1].description == "desc1"
